@@ -194,8 +194,8 @@ def get_stats_xml(db=None, whitelist=None, blacklist=None):
                                     str(result.hit_count[line]) or "0")
                 if line in result.branches:
                     line_element.set('branch', 'true')
-                    line_element.set('condition-coverage', "{0:.2%} ({1:})".format(
-                                        float(result.conditions[line]), result.conditions[line]))
+                    line_element.set('condition-coverage', "{0:}% ({1:})".format(
+                                        int(result.conditions[line]*100), result.conditions[line]))
                 line_elements.append(line_element)
             class_element = E("class", E.methods(), E.lines(*line_elements), name=os.path.basename(result.filename),
                                 complexity='0.00', filename=result.filename)
@@ -213,10 +213,10 @@ def get_stats_xml(db=None, whitelist=None, blacklist=None):
         )
         tree.set('branch-rate', '%1.4f' % (branch_rate or 0.0))
         tree.set('line-rate', '%1.4f' % (line_rate or 0.0))
-        tree.set('lines-covered', line_rate and str(line_rate.denominator) or "0")
-        tree.set('lines-valid', line_rate and str(line_rate.numerator) or "0")
-        tree.set('branches-covered', branch_rate and str(branch_rate.denominator) or "0")
-        tree.set('branches-valid', branch_rate and str(branch_rate.numerator) or "0")
+        tree.set('lines-covered', line_rate and str(line_rate.numerator) or "0")
+        tree.set('lines-valid', line_rate and str(line_rate.denominator) or "0")
+        tree.set('branches-covered', branch_rate and str(branch_rate.numerator) or "0")
+        tree.set('branches-valid', branch_rate and str(branch_rate.denominator) or "0")
         return ET.tostring(tree, pretty_print=True, xml_declaration=True,
                             doctype="<!DOCTYPE coverage SYSTEM 'http://cobertura.sourceforge.net/xml/coverage-04.dtd'>")
 
